@@ -1,4 +1,5 @@
-zoo <- function (x = NULL, order.by = index(x), frequency = NULL) 
+zoo <- function (x = NULL, order.by = index(x), frequency = NULL,
+  calendar = getOption("zoo.calendar", TRUE)) 
 {
     ## process index "order.by"    
     if(length(unique(MATCH(order.by, order.by))) < length(order.by))
@@ -38,6 +39,9 @@ zoo <- function (x = NULL, order.by = index(x), frequency = NULL)
         orig.order.by <- order.by
         order.by <- floor(frequency * order.by + .0001)/frequency
         if(!isTRUE(all.equal(order.by, orig.order.by))) order.by <- orig.order.by
+	if(calendar && frequency %in% c(4, 12)) {
+	  order.by <- if(frequency == 4) as.yearqtr(order.by) else as.yearmon(order.by)	
+	}
       }
     }
 
@@ -217,9 +221,11 @@ str.zoo <- function(object, ...)
   if(NCOL(object) > 0L & is.null(colnames(object))) stop("only possible for zoo series with column names")
   wi <- match(x, colnames(object))
   if(is.na(wi)) {
-    object <- cbind(object, value)
-    if(is.null(dim(object))) dim(object) <- c(length(object), 1)
-    colnames(object)[NCOL(object)] <- x  
+    if(!is.null(value)) {
+      object <- cbind(object, value)
+      if(is.null(dim(object))) dim(object) <- c(length(object), 1)
+      colnames(object)[NCOL(object)] <- x  
+    }
   } else {
     if(is.null(value)) {
       object <- object[, -wi, drop = FALSE]
@@ -322,7 +328,11 @@ ifelse.zoo <- function(test, yes, no) {
 
 mean.zoo <- function(x, ...)  mean(coredata(x), ...)
 
-median.zoo <- function(x, na.rm = FALSE)  median(coredata(x), na.rm = na.rm)
+median.zoo <- if(getRversion() <= "3.3.3") {
+  function(x, na.rm = FALSE) median(coredata(x), na.rm = na.rm)
+} else {
+  function(x, na.rm = FALSE, ...) median(coredata(x), na.rm = na.rm, ...)
+}
 
 quantile.zoo <- function(x, ...) quantile(coredata(x), ...)
 
@@ -351,3 +361,14 @@ transform.zoo <- function(`_data`, ...)
   ## return zoo
   zoo(`_data`, ix, freq)
 }
+
+`dim<-.zoo` <- function(x, value) {
+  d <- dim(x)
+  l <- length(x)
+  ok <- isTRUE(all.equal(d, value)) ||                                  ## no change
+    (is.null(d) && l == 0L && all(value == c(length(index(x)), 0L))) || ## zero-length vector -> 0-column matrix
+    (is.null(d) && l > 0L && all(value == c(l, 1L))) ||                 ## positive-length vector -> 1-column matrix
+    (!is.null(d) && d[2L] <= 1L && is.null(value))                      ## 0- or 1-column matrix -> vector
+  if(!ok) warning("setting this dimension may lead to an invalid zoo object")
+  NextMethod()
+}
